Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(309)

Unified Diff: net/socket/ssl_socket.h

Issue 9663043: Add a boolean |had_context| argument to the TLS ExportKeyingMaterial (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/socket/ssl_socket.h
===================================================================
--- net/socket/ssl_socket.h (revision 125777)
+++ net/socket/ssl_socket.h (working copy)
@@ -18,9 +18,12 @@
virtual ~SSLSocket() {}
// Exports data derived from the SSL master-secret (see RFC 5705).
// The call will fail with an error if the socket is not connected, or the
// SSL implementation does not support the operation.
Ryan Sleevi 2012/03/10 04:23:31 nit: No comma needed here. If you do leave it, the
+ // support the operation.
virtual int ExportKeyingMaterial(const base::StringPiece& label,
+ bool has_context,
const base::StringPiece& context,
unsigned char *out,
unsigned int outlen) = 0;
@@ -18,9 +18,12 @@
virtual ~SSLSocket() {}
// Exports data derived from the SSL master-secret (see RFC 5705).
- // The call will fail with an error if the socket is not connected, or the
- // SSL implementation does not support the operation.
+ // If |has_context| is false, uses the no-context construction from the
+ // RFC and |context| is ignored. The call will fail with an error if
+ // the socket is not connected, or the SSL implementation does not
Ryan Sleevi 2012/03/10 04:23:31 nit: No comma needed here. If you do leave it, the

Powered by Google App Engine
This is Rietveld 408576698